﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;
using Steema.TeeChart.Tools;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 색상 라인
        /// </summary>
        private ColorLine colorLine;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "TChart 클래스 : Legend 속성을 사용해 레전드 항목 스크롤하기";

            this.trackBar.Minimum = 0;
            this.trackBar.Value   = 0;
            this.trackBar.Maximum = 99;

            this.tChart.Panel.Pen = new ChartPen(Color.Black);

            Line line = new Line(this.tChart.Chart);

            line.FillSampleValues(100);

            this.colorLine = new ColorLine(this.tChart.Chart);

            this.colorLine.Pen.Width = 3;
            this.colorLine.Pen.Color = Color.Red;
            this.colorLine.Axis      = this.tChart.Axes.Bottom;

            this.trackBar.ValueChanged += trackBar_ValueChanged;
            this.colorLine.DragLine    += colorLine_DragLine;
            this.colorLine.EndDragLine += colorLine_EndDragLine;

            this.trackBar.Value = 50;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 트랙바 값 변경시 처리하기 - trackBar_ValueChanged(sender, e)

        /// <summary>
        /// 트랙바 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void trackBar_ValueChanged(object sender, EventArgs e)
        {
            this.colorLine.Value = this.trackBar.Value;

            this.tChart.Legend.FirstValue = (int)this.colorLine.Value;
        }

        #endregion
        #region 색상 라인 라인 드래그시 처리하기 - colorLine_DragLine(sender, e)

        /// <summary>
        /// 색상 라인 라인 드래그시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void colorLine_DragLine(object sender, EventArgs e)
        {
            this.trackBar.Value = (int)this.colorLine.Value;
        }

        #endregion
        #region 색상 라인 라인 드래그 종료시 처리하기 - colorLine_EndDragLine(sender)

        /// <summary>
        /// 색상 라인 라인 드래그 종료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        private void colorLine_EndDragLine(object sender)
        {
            this.trackBar.Value= (int)this.colorLine.Value;
        }

        #endregion
    }
}